@@ -9,6 +9,7 @@
 #include <QNetworkAccessManager>
 #include <QNetworkDiskCache>
 #include <QNetworkProxy>
+#include <QByteArray>
 
 
 
@@ -18,41 +19,37 @@ class HttpConnector : public QObject {
 	public:
                 //constructors
                 HttpConnector();
-                HttpConnector(int, int);
+                HttpConnector(int, int=0);
 
-                 //deconstructor
-        //        ~HttpConnector () {
-          //          delete http;
-            //    }
-
-                //public functions
                 void setProxy (QString,int);
-                void connectToHost (QString);
+                void getRequest (QString);
+                void postRequest (QUrl,QByteArray);
                 bool isBusy ();
+                bool hasCookieForUrl (QUrl);
+                void resetCookies ();
 
         public slots:
                 void readResponse ();
-		void requestStarted (int);
-                void requestsDone ();
+
 	
         private slots:
                 void setRequestTimeout ();
 
         signals:
-                // response: statusCode, error, error-msg
-                void getResponseStatus (int,bool,QString);
                 void getResponseContent (bool,QString*);
                 void getRawData (bool,QByteArray);
                 void isFree();
+                void getHttpResponseCode (int);
+
         private:
                 QNetworkAccessManager *http;
                 QNetworkDiskCache *cache;
                 QNetworkReply *reply;
+                QNetworkCookieJar *cookies;
                 int timeout;
                 QTimer *timer;
                 bool busy;
                 QByteArray response;
-
 };
 
 #endif
