@@ -1,9 +1,10 @@
 #include "queueelement.h"
 
-QueueElement::QueueElement (QString _url,QString _id, QString _info) {
+QueueElement::QueueElement (QString _url,QString _id, QString _info,int type) {
     this->id = _id;
     this->url = _url;
     this->info = _info;
+    this->type = type;
 }
 
 QueueElement::QueueElement () {
@@ -24,6 +25,11 @@ QString QueueElement::getURL() {
     return this->url;
 }
 
+int QueueElement::getType() {
+    return type;
+}
+
+
 void QueueElement::setID (QString i) {
     this->id = i;
 }
@@ -36,3 +42,6 @@ void QueueElement::setURL (QString u) {
     this->url = u;
 }
 
+void QueueElement::setType(int t) {
+   type = t;
+}
